@@ -1,4 +1,4 @@
-/* vim: set sw=4: -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* vim: set sw=4 sts=4: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
    rsvg-bpath-util.h: Path utility functions
 
@@ -28,55 +28,49 @@
 
 #include <glib/gtypes.h>
 
-G_BEGIN_DECLS
-
+G_BEGIN_DECLS 
 typedef enum {
-  RSVG_MOVETO,
-  RSVG_MOVETO_OPEN,
-  RSVG_CURVETO,
-  RSVG_LINETO,
-  RSVG_END
+    RSVG_MOVETO,
+    RSVG_MOVETO_OPEN,
+    RSVG_CURVETO,
+    RSVG_LINETO,
+    RSVG_END
 } RsvgPathcode;
 
 typedef struct _RsvgBpath RsvgBpath;
 struct _RsvgBpath {
-  /*< public >*/
-  RsvgPathcode code;
-  double x1;
-  double y1;
-  double x2;
-  double y2;
-  double x3;
-  double y3;
+    /*< public > */
+    RsvgPathcode code;
+    double x1;
+    double y1;
+    double x2;
+    double y2;
+    double x3;
+    double y3;
 };
 
 typedef struct _RsvgBpathDef RsvgBpathDef;
 
 struct _RsvgBpathDef {
-	RsvgBpath *bpath;
-	int n_bpath;
-	int n_bpath_max;
-	int moveto_idx;
+    RsvgBpath *bpath;
+    int n_bpath;
+    int n_bpath_max;
+    int moveto_idx;
 };
 
-RsvgBpathDef *rsvg_bpath_def_new (void);
-RsvgBpathDef *rsvg_bpath_def_new_from (RsvgBpath *bpath);
+RsvgBpathDef *rsvg_bpath_def_new	(void);
+RsvgBpathDef *rsvg_bpath_def_new_from	(RsvgBpath * bpath);
 
-void rsvg_bpath_def_free       (RsvgBpathDef *bpd);
+void rsvg_bpath_def_free	(RsvgBpathDef * bpd);
 
-void rsvg_bpath_def_moveto     (RsvgBpathDef *bpd,
-								double x, double y);
-void rsvg_bpath_def_lineto     (RsvgBpathDef *bpd,
-								double x, double y);
-void rsvg_bpath_def_curveto    (RsvgBpathDef *bpd,
-								double x1, double y1,
-								double x2, double y2,
-								double x3, double y3);
-void rsvg_bpath_def_closepath  (RsvgBpathDef *bpd);
+void rsvg_bpath_def_moveto	(RsvgBpathDef * bpd, double x, double y);
+void rsvg_bpath_def_lineto	(RsvgBpathDef * bpd, double x, double y);
+void rsvg_bpath_def_curveto	(RsvgBpathDef * bpd,
+				 double x1, double y1, double x2, double y2, double x3, double y3);
+void rsvg_bpath_def_closepath	(RsvgBpathDef * bpd);
 
-void rsvg_bpath_def_art_finish (RsvgBpathDef *bpd);
+void rsvg_bpath_def_art_finish	(RsvgBpathDef * bpd);
 
 G_END_DECLS
 
 #endif
-
